newcm

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 21, 2025 License: BSD-3-Clause Imports: 0 Imported by: 0

README

newcm

Release GoDoc License

newcm provides the New Computer Modern fonts as importable Go packages.

The fonts are released under the GUST font license. The Go packages under the BSD-3 license.

Example

import (
	"fmt"
	"log"

	"codeberg.org/go-fonts/newcm/newcmmathbook"
	"golang.org/x/image/font/sfnt"
)

func Example() {
	ttf, err := sfnt.Parse(newcmmathbook.TTF)
	if err != nil {
		log.Fatalf("could not parse New Computer Modern Math font: %+v", err)
	}
	fmt.Printf("num glyphs: %d\n", ttf.NumGlyphs())

	// Output:
	// num glyphs: 7659
}

Documentation

Overview

Package lm holds TTF data of the New Computer Modern fonts.

Example
package main

import (
	"fmt"
	"log"

	"codeberg.org/go-fonts/newcm/newcmmathbook"
	"golang.org/x/image/font/sfnt"
)

func main() {
	ttf, err := sfnt.Parse(newcmmathbook.TTF)
	if err != nil {
		log.Fatalf("could not parse New Computer Modern Math font: %+v", err)
	}
	fmt.Printf("num glyphs: %d\n", ttf.NumGlyphs())

}
Output:
num glyphs: 7659

Directories

Path Synopsis
Package newcm08book provides the "NewCM08 Book" TrueType font from the New Computer Modern font family.
Package newcm08book provides the "NewCM08 Book" TrueType font from the New Computer Modern font family.
Package newcm08bookitalic provides the "NewCM08 BookItalic" TrueType font from the New Computer Modern font family.
Package newcm08bookitalic provides the "NewCM08 BookItalic" TrueType font from the New Computer Modern font family.
Package newcm08devanagaribook provides the "NewCM08Devanagari Book" TrueType font from the New Computer Modern font family.
Package newcm08devanagaribook provides the "NewCM08Devanagari Book" TrueType font from the New Computer Modern font family.
Package newcm08devanagariregular provides the "NewCM08Devanagari Regular" TrueType font from the New Computer Modern font family.
Package newcm08devanagariregular provides the "NewCM08Devanagari Regular" TrueType font from the New Computer Modern font family.
Package newcm08italic provides the "NewCM08 Italic" TrueType font from the New Computer Modern font family.
Package newcm08italic provides the "NewCM08 Italic" TrueType font from the New Computer Modern font family.
Package newcm08regular provides the "NewCM08 Regular" TrueType font from the New Computer Modern font family.
Package newcm08regular provides the "NewCM08 Regular" TrueType font from the New Computer Modern font family.
Package newcm10bold provides the "NewCM10 Bold" TrueType font from the New Computer Modern font family.
Package newcm10bold provides the "NewCM10 Bold" TrueType font from the New Computer Modern font family.
Package newcm10bolditalic provides the "NewCM10 BoldItalic" TrueType font from the New Computer Modern font family.
Package newcm10bolditalic provides the "NewCM10 BoldItalic" TrueType font from the New Computer Modern font family.
Package newcm10book provides the "NewCM10 Book" TrueType font from the New Computer Modern font family.
Package newcm10book provides the "NewCM10 Book" TrueType font from the New Computer Modern font family.
Package newcm10bookitalic provides the "NewCM10 BookItalic" TrueType font from the New Computer Modern font family.
Package newcm10bookitalic provides the "NewCM10 BookItalic" TrueType font from the New Computer Modern font family.
Package newcm10devanagaribold provides the "NewCM10Devanagari Bold" TrueType font from the New Computer Modern font family.
Package newcm10devanagaribold provides the "NewCM10Devanagari Bold" TrueType font from the New Computer Modern font family.
Package newcm10devanagaribook provides the "NewCM10Devanagari Book" TrueType font from the New Computer Modern font family.
Package newcm10devanagaribook provides the "NewCM10Devanagari Book" TrueType font from the New Computer Modern font family.
Package newcm10devanagariregular provides the "NewCM10Devanagari Regular" TrueType font from the New Computer Modern font family.
Package newcm10devanagariregular provides the "NewCM10Devanagari Regular" TrueType font from the New Computer Modern font family.
Package newcm10italic provides the "NewCM10 Italic" TrueType font from the New Computer Modern font family.
Package newcm10italic provides the "NewCM10 Italic" TrueType font from the New Computer Modern font family.
Package newcm10regular provides the "NewCM10 Regular" TrueType font from the New Computer Modern font family.
Package newcm10regular provides the "NewCM10 Regular" TrueType font from the New Computer Modern font family.
Package newcmmathbold provides the "NewCMMath Bold" TrueType font from the New Computer Modern font family.
Package newcmmathbold provides the "NewCMMath Bold" TrueType font from the New Computer Modern font family.
Package newcmmathbook provides the "NewCMMath Book" TrueType font from the New Computer Modern font family.
Package newcmmathbook provides the "NewCMMath Book" TrueType font from the New Computer Modern font family.
Package newcmmathregular provides the "NewCMMath Regular" TrueType font from the New Computer Modern font family.
Package newcmmathregular provides the "NewCMMath Regular" TrueType font from the New Computer Modern font family.
Package newcmmono10bold provides the "NewCMMono10 Bold" TrueType font from the New Computer Modern font family.
Package newcmmono10bold provides the "NewCMMono10 Bold" TrueType font from the New Computer Modern font family.
Package newcmmono10boldoblique provides the "NewCMMono10 BoldOblique" TrueType font from the New Computer Modern font family.
Package newcmmono10boldoblique provides the "NewCMMono10 BoldOblique" TrueType font from the New Computer Modern font family.
Package newcmmono10book provides the "NewCMMono10 Book" TrueType font from the New Computer Modern font family.
Package newcmmono10book provides the "NewCMMono10 Book" TrueType font from the New Computer Modern font family.
Package newcmmono10bookitalic provides the "NewCMMono10 BookItalic" TrueType font from the New Computer Modern font family.
Package newcmmono10bookitalic provides the "NewCMMono10 BookItalic" TrueType font from the New Computer Modern font family.
Package newcmmono10italic provides the "NewCMMono10 Italic" TrueType font from the New Computer Modern font family.
Package newcmmono10italic provides the "NewCMMono10 Italic" TrueType font from the New Computer Modern font family.
Package newcmmono10regular provides the "NewCMMono10 Regular" TrueType font from the New Computer Modern font family.
Package newcmmono10regular provides the "NewCMMono10 Regular" TrueType font from the New Computer Modern font family.
Package newcmsans08book provides the "NewCMSans08 Book" TrueType font from the New Computer Modern font family.
Package newcmsans08book provides the "NewCMSans08 Book" TrueType font from the New Computer Modern font family.
Package newcmsans08bookoblique provides the "NewCMSans08 BookOblique" TrueType font from the New Computer Modern font family.
Package newcmsans08bookoblique provides the "NewCMSans08 BookOblique" TrueType font from the New Computer Modern font family.
Package newcmsans08oblique provides the "NewCMSans08 Oblique" TrueType font from the New Computer Modern font family.
Package newcmsans08oblique provides the "NewCMSans08 Oblique" TrueType font from the New Computer Modern font family.
Package newcmsans08regular provides the "NewCMSans08 Regular" TrueType font from the New Computer Modern font family.
Package newcmsans08regular provides the "NewCMSans08 Regular" TrueType font from the New Computer Modern font family.
Package newcmsans10bold provides the "NewCMSans10 Bold" TrueType font from the New Computer Modern font family.
Package newcmsans10bold provides the "NewCMSans10 Bold" TrueType font from the New Computer Modern font family.
Package newcmsans10boldoblique provides the "NewCMSans10 BoldOblique" TrueType font from the New Computer Modern font family.
Package newcmsans10boldoblique provides the "NewCMSans10 BoldOblique" TrueType font from the New Computer Modern font family.
Package newcmsans10book provides the "NewCMSans10 Book" TrueType font from the New Computer Modern font family.
Package newcmsans10book provides the "NewCMSans10 Book" TrueType font from the New Computer Modern font family.
Package newcmsans10bookoblique provides the "NewCMSans10 BookOblique" TrueType font from the New Computer Modern font family.
Package newcmsans10bookoblique provides the "NewCMSans10 BookOblique" TrueType font from the New Computer Modern font family.
Package newcmsans10oblique provides the "NewCMSans10 Oblique" TrueType font from the New Computer Modern font family.
Package newcmsans10oblique provides the "NewCMSans10 Oblique" TrueType font from the New Computer Modern font family.
Package newcmsans10regular provides the "NewCMSans10 Regular" TrueType font from the New Computer Modern font family.
Package newcmsans10regular provides the "NewCMSans10 Regular" TrueType font from the New Computer Modern font family.
Package newcmsansmathregular provides the "NewCMSansMath Regular" TrueType font from the New Computer Modern font family.
Package newcmsansmathregular provides the "NewCMSansMath Regular" TrueType font from the New Computer Modern font family.
Package newcmuncial08bold provides the "NewCMUncial08 Bold" TrueType font from the New Computer Modern font family.
Package newcmuncial08bold provides the "NewCMUncial08 Bold" TrueType font from the New Computer Modern font family.
Package newcmuncial08book provides the "NewCMUncial08 Book" TrueType font from the New Computer Modern font family.
Package newcmuncial08book provides the "NewCMUncial08 Book" TrueType font from the New Computer Modern font family.
Package newcmuncial08regular provides the "NewCMUncial08 Regular" TrueType font from the New Computer Modern font family.
Package newcmuncial08regular provides the "NewCMUncial08 Regular" TrueType font from the New Computer Modern font family.
Package newcmuncial10bold provides the "NewCMUncial10 Bold" TrueType font from the New Computer Modern font family.
Package newcmuncial10bold provides the "NewCMUncial10 Bold" TrueType font from the New Computer Modern font family.
Package newcmuncial10book provides the "NewCMUncial10 Book" TrueType font from the New Computer Modern font family.
Package newcmuncial10book provides the "NewCMUncial10 Book" TrueType font from the New Computer Modern font family.
Package newcmuncial10regular provides the "NewCMUncial10 Regular" TrueType font from the New Computer Modern font family.
Package newcmuncial10regular provides the "NewCMUncial10 Regular" TrueType font from the New Computer Modern font family.

Jump to